Displaying 8 results from an estimated 8 matches for "vdsm_disk_creat".
Did you mean:
vdsm_disk_create
2015 Nov 10
0
[PATCH 4/4] mllib, v2v: Allow open_guestfs to set the handle identifier.
...b/v2v/output_vdsm.ml
index 079b47f..3c667f3 100644
--- a/v2v/output_vdsm.ml
+++ b/v2v/output_vdsm.ml
@@ -156,8 +156,7 @@ object
method disk_create ?backingfile ?backingformat ?preallocation ?compat
?clustersize path format size =
- let g = open_guestfs () in
- g#set_identifier "vdsm_disk_create";
+ let g = open_guestfs ~identifier:"vdsm_disk_create" () in
(* For qcow2, override v2v-supplied compat option, because RHEL 6
* nodes cannot handle qcow2 v3 (RHBZ#1145582).
*)
diff --git a/v2v/v2v.ml b/v2v/v2v.ml
index 7e8b459..f01a790 100644
--- a/v2v/v2v.ml
+...
2015 Nov 10
7
[PATCH 0/4]: mllib: Add 'may' function, and refactoring.
The 'may' function is a higher-order function (HOF) that replaces:
match x with
| None -> ()
| Some x -> f x
with:
may f x
The idea comes from lablgtk (OCaml Gtk bindings) where it is widely
used.
If this change is clearer than previous code, then this could be used
in many more places. However I previously steered clear from using
HOFs like this because they can be
2016 Nov 30
0
[PATCH] v2v: -o vdsm, -o rhev: Don't create compat=0.10 images;
...2ce5c0 100644
--- a/v2v/output_vdsm.ml
+++ b/v2v/output_vdsm.ml
@@ -145,16 +145,6 @@ object
(* Return the list of targets. *)
targets
- method disk_create ?backingfile ?backingformat ?preallocation ?compat
- ?clustersize path format size =
- let g = open_guestfs ~identifier:"vdsm_disk_create" () in
- (* For qcow2, override v2v-supplied compat option, because RHEL 6
- * nodes cannot handle qcow2 v3 (RHBZ#1145582).
- *)
- let compat = if format <> "qcow2" then compat else Some "0.10" in
- g#disk_create ?backingfile ?backingformat ?prealloc...
2015 Oct 21
2
[PATCH] v2v: use open_guestfs everywhere
...b47f 100644
--- a/v2v/output_vdsm.ml
+++ b/v2v/output_vdsm.ml
@@ -156,7 +156,7 @@ object
method disk_create ?backingfile ?backingformat ?preallocation ?compat
?clustersize path format size =
- let g = new Guestfs.guestfs () in
+ let g = open_guestfs () in
g#set_identifier "vdsm_disk_create";
(* For qcow2, override v2v-supplied compat option, because RHEL 6
* nodes cannot handle qcow2 v3 (RHBZ#1145582).
diff --git a/v2v/types.ml b/v2v/types.ml
index a295172..038d259 100644
--- a/v2v/types.ml
+++ b/v2v/types.ml
@@ -401,7 +401,7 @@ class virtual output = object
metho...
2015 Oct 21
0
Re: [PATCH] v2v: use open_guestfs everywhere
...; +++ b/v2v/output_vdsm.ml
> @@ -156,7 +156,7 @@ object
>
> method disk_create ?backingfile ?backingformat ?preallocation ?compat
> ?clustersize path format size =
> - let g = new Guestfs.guestfs () in
> + let g = open_guestfs () in
> g#set_identifier "vdsm_disk_create";
> (* For qcow2, override v2v-supplied compat option, because RHEL 6
> * nodes cannot handle qcow2 v3 (RHBZ#1145582).
> diff --git a/v2v/types.ml b/v2v/types.ml
> index a295172..038d259 100644
> --- a/v2v/types.ml
> +++ b/v2v/types.ml
> @@ -401,7 +401,7 @@ cla...
2016 Dec 01
1
[PATCH v2] v2v: -o vdsm: Add --vdsm-compat-11 flag, -o rhev: Drop support for RHV < 4.1 (RHBZ#1400205).
...vdsm_params.vm_uuid
vdsm_params.ovf_output
+ (if vdsm_params.compat_11 then " --vdsm-compat-11" else "")
method supported_firmware = [ TargetBIOS ]
@@ -149,9 +151,12 @@ object
?clustersize path format size =
let g = open_guestfs ~identifier:"vdsm_disk_create" () in
(* For qcow2, override v2v-supplied compat option, because RHEL 6
* nodes cannot handle qcow2 v3 (RHBZ#1145582).
*)
- let compat = if format <> "qc...
[PATCH v3] v2v: -o vdsm: Add --vdsm-compat flag. -o rhev: Drop support for RHV < 4.1 (RHBZ#1400205).
2016 Dec 07
0
[PATCH v3] v2v: -o vdsm: Add --vdsm-compat flag. -o rhev: Drop support for RHV < 4.1 (RHBZ#1400205).
...ot; -> "" (* currently this is the default, so don't print it *)
+ | s -> sprintf " --vdsm-compat=%s" s)
method supported_firmware = [ TargetBIOS ]
@@ -149,9 +153,10 @@ object
?clustersize path format size =
let g = open_guestfs ~identifier:"vdsm_disk_create" () in
(* For qcow2, override v2v-supplied compat option, because RHEL 6
- * nodes cannot handle qcow2 v3 (RHBZ#1145582).
+ * nodes cannot handle qcow2 v3 (RHBZ#1145582, RHBZ#1400205).
*)
- let compat = if format <> "qcow2" then compat else Some "0.1...
2016 Dec 07
2
[PATCH v3] v2v: -o vdsm: Add --vdsm-compat flag.
@@ -149,9 +151,12 @@ object
let g = open_guestfs ~identifier:"vdsm_disk_create" () in
(* For qcow2, override v2v-supplied compat option, because RHEL 6
- * nodes cannot handle qcow2 v3 (RHBZ#1145582).
+ * nodes cannot handle qcow2 v3 (RHBZ#1145582). Using
+ * --vdsm-compat-11 disables the override.
*)
v3:
Change the flag from --vdsm-compat-11 to --vdsm-compat=1.1
Also the --machine-readable output has changed.
I have also added a test.
Rich.